Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8)

Unified Diff: components/sync/driver/directory_data_type_controller.h

Issue 2533083002: [Sync] SyncEngine refactor part 1: interfaces. (Closed)
Patch Set: Rebase. Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/sync/driver/directory_data_type_controller.h
diff --git a/components/sync/driver/directory_data_type_controller.h b/components/sync/driver/directory_data_type_controller.h
index 2b2051c17377dbd8cf0a50175cd201ebecc6a82a..48571e691fa61a803f88ef2e3414d7ca8bf303c6 100644
--- a/components/sync/driver/directory_data_type_controller.h
+++ b/components/sync/driver/directory_data_type_controller.h
@@ -29,21 +29,21 @@ class DirectoryDataTypeController : public DataTypeController {
// Directory based data types don't need to register with backend.
// ModelTypeRegistry will create all necessary objects in
// SetEnabledDirectoryTypes based on routing info.
- void RegisterWithBackend(BackendDataTypeConfigurer* configurer) override;
+ void RegisterWithBackend(ModelTypeConfigurer* configurer) override;
// Directory specific implementation of ActivateDataType with the
// type specific ChangeProcessor and ModelSafeGroup.
// Activates change processing on the controlled data type.
// This is called by DataTypeManager, synchronously with data type's
// model association.
- // See BackendDataTypeConfigurer::ActivateDataType for more details.
- void ActivateDataType(BackendDataTypeConfigurer* configurer) override;
+ // See ModelTypeConfigurer::ActivateDataType for more details.
+ void ActivateDataType(ModelTypeConfigurer* configurer) override;
// Directory specific implementation of DeactivateDataType.
// Deactivates change processing on the controlled data type (by removing
// the data type's ChangeProcessor registration with the backend).
- // See BackendDataTypeConfigurer::DeactivateDataType for more details.
- void DeactivateDataType(BackendDataTypeConfigurer* configurer) override;
+ // See ModelTypeConfigurer::DeactivateDataType for more details.
+ void DeactivateDataType(ModelTypeConfigurer* configurer) override;
// Returns a ListValue representing all nodes for a specified type by querying
// the directory.
« no previous file with comments | « components/sync/driver/data_type_manager_impl_unittest.cc ('k') | components/sync/driver/directory_data_type_controller.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698